@@ -1,7 +1,3 @@
-import numpy as np
-from scrapeasy import Webpage
-import time
-
 class Class1:
     def __init__(self, name, age):
         self.name = name
